@@ -35,13 +35,12 @@
 #include "kpView.h"
 #include "kpViewPrivate.h"
 
-#include <math.h>
-#include <stdlib.h>
+#include <cstdlib>
 
-#include <qcursor.h>
-#include <qpoint.h>
-#include <qrect.h>
-#include <qregion.h>
+#include <QCursor>
+#include <QPoint>
+#include <QRect>
+#include <QRegion>
 #include <QScrollBar>
 
 #include "kpLogCategories.h"
@@ -77,7 +76,8 @@ kpView::kpView (kpDocument *document,
     d->buddyView = buddyView;
     d->scrollableContainer = scrollableContainer;
 
-    d->hzoom = 100, d->vzoom = 100;
+    d->hzoom = 100;
+    d->vzoom = 100;
     d->origin = QPoint (0, 0);
     d->showGrid = false;
     d->isBuddyViewScrollableContainerRectangleShown = false;
@@ -165,13 +165,13 @@ kpViewScrollableContainer *kpView::scrollableContainer () const
 
 
 // public
-int kpView::zoomLevelX (void) const
+int kpView::zoomLevelX () const
 {
     return d->hzoom;
 }
 
 // public
-int kpView::zoomLevelY (void) const
+int kpView::zoomLevelY () const
 {
     return d->vzoom;
 }
@@ -182,14 +182,16 @@ void kpView::setZoomLevel (int hzoom, int vzoom)
     hzoom = qBound (MinZoomLevel, hzoom, MaxZoomLevel);
     vzoom = qBound (MinZoomLevel, vzoom, MaxZoomLevel);
 
-    if (hzoom == d->hzoom && vzoom == d->vzoom)
+    if (hzoom == d->hzoom && vzoom == d->vzoom) {
         return;
+    }
 
     d->hzoom = hzoom;
     d->vzoom = vzoom;
 
-    if (viewManager ())
+    if (viewManager ()) {
         viewManager ()->updateView (this);
+    }
 
     emit zoomLevelChanged (hzoom, vzoom);
 }
@@ -218,8 +220,9 @@ void kpView::setOrigin (const QPoint &origin)
 
     d->origin = origin;
 
-    if (viewManager ())
+    if (viewManager ()) {
         viewManager ()->updateView (this);
+    }
 
     emit originChanged (origin);
 }
@@ -243,16 +246,19 @@ bool kpView::isGridShown () const
 // public
 void kpView::showGrid (bool yes)
 {
-    if (d->showGrid == yes)
+    if (d->showGrid == yes) {
         return;
+    }
 
-    if (yes && !canShowGrid ())
+    if (yes && !canShowGrid ()) {
         return;
+    }
 
     d->showGrid = yes;
 
-    if (viewManager ())
+    if (viewManager ()) {
         viewManager ()->updateView (this);
+    }
 }
 
 
@@ -265,8 +271,9 @@ bool kpView::isBuddyViewScrollableContainerRectangleShown () const
 // public
 void kpView::showBuddyViewScrollableContainerRectangle (bool yes)
 {
-    if (yes == d->isBuddyViewScrollableContainerRectangleShown)
+    if (yes == d->isBuddyViewScrollableContainerRectangleShown) {
         return;
+    }
 
     d->isBuddyViewScrollableContainerRectangleShown = yes;
 
@@ -275,55 +282,65 @@ void kpView::showBuddyViewScrollableContainerRectangle (bool yes)
         // Got these connect statements by analysing deps of
         // updateBuddyViewScrollableContainerRectangle() rect update code.
 
-        connect (this, SIGNAL (zoomLevelChanged(int,int)),
-                 this, SLOT (updateBuddyViewScrollableContainerRectangle()));
-        connect (this, SIGNAL (originChanged(QPoint)),
-                 this, SLOT (updateBuddyViewScrollableContainerRectangle()));
+        connect (this, &kpView::zoomLevelChanged,
+                 this, &kpView::updateBuddyViewScrollableContainerRectangle);
+
+        connect (this, &kpView::originChanged,
+                 this, &kpView::updateBuddyViewScrollableContainerRectangle);
 
         if (buddyViewScrollableContainer ())
         {
-            connect (buddyViewScrollableContainer (), SIGNAL (contentsMoved()),
-                     this, SLOT (updateBuddyViewScrollableContainerRectangle()));
-            connect (buddyViewScrollableContainer (), SIGNAL (resized()),
-                     this, SLOT (updateBuddyViewScrollableContainerRectangle()));
+            connect (buddyViewScrollableContainer (),
+                     &kpViewScrollableContainer::contentsMoved,
+                     this, &kpView::updateBuddyViewScrollableContainerRectangle);
+
+            connect (buddyViewScrollableContainer (), &kpViewScrollableContainer::resized,
+                     this, &kpView::updateBuddyViewScrollableContainerRectangle);
         }
 
         if (buddyView ())
         {
-            connect (buddyView (), SIGNAL (zoomLevelChanged(int,int)),
-                     this, SLOT (updateBuddyViewScrollableContainerRectangle()));
-            connect (buddyView (), SIGNAL (originChanged(QPoint)),
-                     this, SLOT (updateBuddyViewScrollableContainerRectangle()));
+            connect (buddyView (), &kpView::zoomLevelChanged,
+                     this, &kpView::updateBuddyViewScrollableContainerRectangle);
 
-            connect (buddyView (), SIGNAL (sizeChanged(int,int)),
-                     this, SLOT (updateBuddyViewScrollableContainerRectangle()));
+            connect (buddyView (), &kpView::originChanged,
+                     this, &kpView::updateBuddyViewScrollableContainerRectangle);
+
+            connect (buddyView (),
+                     static_cast<void (kpView::*)(int,int)>(&kpView::sizeChanged),
+                     this, &kpView::updateBuddyViewScrollableContainerRectangle);
         }
 
     }
     else
     {
-        disconnect (this, SIGNAL (zoomLevelChanged(int,int)),
-                    this, SLOT (updateBuddyViewScrollableContainerRectangle()));
-        disconnect (this, SIGNAL (originChanged(QPoint)),
-                    this, SLOT (updateBuddyViewScrollableContainerRectangle()));
+        disconnect (this, &kpView::zoomLevelChanged,
+                    this, &kpView::updateBuddyViewScrollableContainerRectangle);
+
+        disconnect (this, &kpView::originChanged,
+                 this, &kpView::updateBuddyViewScrollableContainerRectangle);
 
         if (buddyViewScrollableContainer ())
         {
-            disconnect (buddyViewScrollableContainer (), SIGNAL (contentsMoved()),
-                        this, SLOT (updateBuddyViewScrollableContainerRectangle()));
-            disconnect (buddyViewScrollableContainer (), SIGNAL (resized()),
-                        this, SLOT (updateBuddyViewScrollableContainerRectangle()));
+            disconnect (buddyViewScrollableContainer (),
+                     &kpViewScrollableContainer::contentsMoved,
+                     this, &kpView::updateBuddyViewScrollableContainerRectangle);
+
+            disconnect (buddyViewScrollableContainer (), &kpViewScrollableContainer::resized,
+                     this, &kpView::updateBuddyViewScrollableContainerRectangle);
         }
 
         if (buddyView ())
         {
-            disconnect (buddyView (), SIGNAL (zoomLevelChanged(int,int)),
-                        this, SLOT (updateBuddyViewScrollableContainerRectangle()));
-            disconnect (buddyView (), SIGNAL (originChanged(QPoint)),
-                        this, SLOT (updateBuddyViewScrollableContainerRectangle()));
+            disconnect (buddyView (), &kpView::zoomLevelChanged,
+                     this, &kpView::updateBuddyViewScrollableContainerRectangle);
 
-            disconnect (buddyView (), SIGNAL (sizeChanged(int,int)),
-                        this, SLOT (updateBuddyViewScrollableContainerRectangle()));
+            disconnect (buddyView (), &kpView::originChanged,
+                     this, &kpView::updateBuddyViewScrollableContainerRectangle);
+
+            disconnect (buddyView (),
+                     static_cast<void (kpView::*)(int,int)>(&kpView::sizeChanged),
+                     this, &kpView::updateBuddyViewScrollableContainerRectangle);
         }
 
     }
@@ -341,8 +358,9 @@ QRect kpView::buddyViewScrollableContainerRectangle () const
 // protected slot
 void kpView::updateBuddyViewScrollableContainerRectangle ()
 {
-    if (viewManager ())
+    if (viewManager ()) {
         viewManager ()->setQueueUpdates ();
+    }
 
     {
         if (d->buddyViewScrollableContainerRectangle.isValid ())
@@ -401,8 +419,9 @@ void kpView::updateBuddyViewScrollableContainerRectangle ()
         }
     }
 
-    if (viewManager ())
+    if (viewManager ()) {
         viewManager ()->restoreQueueUpdates ();
+    }
 }
 
 //---------------------------------------------------------------------
@@ -426,8 +445,8 @@ double kpView::transformViewToDocY (double viewY) const
 // public
 QPoint kpView::transformViewToDoc (const QPoint &viewPoint) const
 {
-    return QPoint ((int) transformViewToDocX (viewPoint.x ()),
-                   (int) transformViewToDocY (viewPoint.y ()));
+    return  {static_cast<int> (transformViewToDocX (viewPoint.x ())),
+                   static_cast<int> (transformViewToDocY (viewPoint.y ()))};
 }
 
 //---------------------------------------------------------------------
@@ -437,22 +456,19 @@ QRect kpView::transformViewToDoc (const QRect &viewRect) const
 {
     if (zoomLevelX () == 100 && zoomLevelY () == 100)
     {
-        return QRect (viewRect.x () - origin ().x (),
-                      viewRect.y () - origin ().y (),
-                      viewRect.width (),
-                      viewRect.height ());
+        return  {viewRect.x () - origin ().x (), viewRect.y () - origin ().y (),
+                    viewRect.width (), viewRect.height ()};
     }
-    else
-    {
-        const QPoint docTopLeft = transformViewToDoc (viewRect.topLeft ());
 
-        // (don't call transformViewToDoc[XY]() - need to round up dimensions)
-        const int docWidth = qRound (double (viewRect.width ()) * 100.0 / double (zoomLevelX ()));
-        const int docHeight = qRound (double (viewRect.height ()) * 100.0 / double (zoomLevelY ()));
+    const QPoint docTopLeft = transformViewToDoc (viewRect.topLeft ());
+
+    // (don't call transformViewToDoc[XY]() - need to round up dimensions)
+    const auto docWidth = qRound (double (viewRect.width ()) * 100.0 / double (zoomLevelX ()));
+    const auto docHeight = qRound (double (viewRect.height ()) * 100.0 / double (zoomLevelY ()));
+
+    // (like QWMatrix::Areas)
+    return  {docTopLeft.x (), docTopLeft.y (), docWidth, docHeight};
 
-        // (like QWMatrix::Areas)
-        return QRect (docTopLeft.x (), docTopLeft.y (), docWidth, docHeight);
-    }
 }
 
 //---------------------------------------------------------------------
@@ -472,8 +488,8 @@ double kpView::transformDocToViewY (double docY) const
 // public
 QPoint kpView::transformDocToView (const QPoint &docPoint) const
 {
-    return QPoint ((int) transformDocToViewX (docPoint.x ()),
-                   (int) transformDocToViewY (docPoint.y ()));
+    return  {static_cast<int> (transformDocToViewX (docPoint.x ())),
+                static_cast<int> (transformDocToViewY (docPoint.y ()))};
 }
 
 // public
@@ -481,22 +497,18 @@ QRect kpView::transformDocToView (const QRect &docRect) const
 {
     if (zoomLevelX () == 100 && zoomLevelY () == 100)
     {
-        return QRect (docRect.x () + origin ().x (),
-                      docRect.y () + origin ().y (),
-                      docRect.width (),
-                      docRect.height ());
+        return  {docRect.x () + origin ().x (), docRect.y () + origin ().y (),
+                    docRect.width (), docRect.height ()};
     }
-    else
-    {
-        const QPoint viewTopLeft = transformDocToView (docRect.topLeft ());
 
-        // (don't call transformDocToView[XY]() - need to round up dimensions)
-        const int viewWidth = qRound (double (docRect.width ()) * double (zoomLevelX ()) / 100.0);
-        const int viewHeight = qRound (double (docRect.height ()) * double (zoomLevelY ()) / 100.0);
+    const QPoint viewTopLeft = transformDocToView (docRect.topLeft ());
 
-        // (like QWMatrix::Areas)
-        return QRect (viewTopLeft.x (), viewTopLeft.y (), viewWidth, viewHeight);
-    }
+    // (don't call transformDocToView[XY]() - need to round up dimensions)
+    const int viewWidth = qRound (double (docRect.width ()) * double (zoomLevelX ()) / 100.0);
+    const int viewHeight = qRound (double (docRect.height ()) * double (zoomLevelY ()) / 100.0);
+
+    // (like QWMatrix::Areas)
+    return QRect (viewTopLeft.x (), viewTopLeft.y (), viewWidth, viewHeight);
 }
 
 
@@ -504,8 +516,9 @@ QRect kpView::transformDocToView (const QRect &docRect) const
 QPoint kpView::transformViewToOtherView (const QPoint &viewPoint,
                                          const kpView *otherView)
 {
-    if (this == otherView)
+    if (this == otherView) {
         return viewPoint;
+    }
 
     const double docX = transformViewToDocX (viewPoint.x ());
     const double docY = transformViewToDocY (viewPoint.y ());
@@ -513,7 +526,7 @@ QPoint kpView::transformViewToOtherView (const QPoint &viewPoint,
     const double otherViewX = otherView->transformDocToViewX (docX);
     const double otherViewY = otherView->transformDocToViewY (docY);
 
-    return QPoint ((int) otherViewX, (int) otherViewY);
+    return  {static_cast<int> (otherViewX), static_cast<int> (otherViewY)};
 }
 
 
@@ -534,20 +547,22 @@ int kpView::zoomedDocHeight () const
 void kpView::setHasMouse (bool yes)
 {
     kpViewManager *vm = viewManager ();
-    if (!vm)
+    if (!vm) {
         return;
+    }
 
 #if DEBUG_KP_VIEW && 0
     qCDebug(kpLogViews) << "kpView(" << objectName ()
                << ")::setHasMouse(" << yes
                << ") existing viewUnderCursor="
-               << (vm->viewUnderCursor () ? vm->viewUnderCursor ()->objectName () : "(none)")
-               << endl;
+               << (vm->viewUnderCursor () ? vm->viewUnderCursor ()->objectName () : "(none)");
 #endif
-    if (yes && vm->viewUnderCursor () != this)
+    if (yes && vm->viewUnderCursor () != this) {
         vm->setViewUnderCursor (this);
-    else if (!yes && vm->viewUnderCursor () == this)
+    }
+    else if (!yes && vm->viewUnderCursor () == this) {
         vm->setViewUnderCursor (nullptr);
+    }
 }
 
 //---------------------------------------------------------------------
@@ -605,14 +620,17 @@ void kpView::updateQueuedArea ()
                << endl;
 #endif
 
-    if (!vm)
+    if (!vm) {
         return;
+    }
 
-    if (vm->queueUpdates ())
+    if (vm->queueUpdates ()) {
         return;
+    }
 
-    if (!d->queuedUpdateArea.isEmpty ())
+    if (!d->queuedUpdateArea.isEmpty ()) {
         vm->updateView (this, d->queuedUpdateArea);
+    }
 
     invalidateQueuedArea ();
 }
@@ -622,14 +640,13 @@ void kpView::updateQueuedArea ()
 // public
 QPoint kpView::mouseViewPoint (const QPoint &returnViewPoint) const
 {
-    if (returnViewPoint != KP_INVALID_POINT)
+    if (returnViewPoint != KP_INVALID_POINT) {
         return returnViewPoint;
-    else
-    {
-        // TODO: I don't think this is right for the main view since that's
-        //       inside the scrollview (which can scroll).
-        return mapFromGlobal (QCursor::pos ());
     }
+
+    // TODO: I don't think this is right for the main view since that's
+    //       inside the scrollview (which can scroll).
+    return mapFromGlobal (QCursor::pos ());
 }
 
 //---------------------------------------------------------------------
